@@ -1,9 +1,13 @@
 `alias.cca` <-
-    function (object, names.only = FALSE, ...) 
+    function (object, names.only = FALSE, ...)
 {
-    if (is.null(object$CCA$alias))
+    if (is.null(object$CCA))
         stop("no constrained component, 'alias' cannot be applied")
-    if (names.only)
+    if (is.null(object$CCA$alias))
+        stop("no aliased terms")
+    ## if we do not return CCA$QR from zero-rank components, we cannot
+    ## have aliasing equation and have to return only names
+    if (names.only || is.null(object$CCA$QR))
         return(object$CCA$alias)
     CompPatt <- function(x, ...) {
         x[abs(x) < 1e-06] <- 0
@@ -20,7 +24,7 @@
     d <- dim(R)
     rank <- object$CCA$QR$rank
     p <- d[2]
-    value$Complete <- if (is.null(p) || rank == p) 
+    value$Complete <- if (is.null(p) || rank == p)
         NULL
     else {
         p1 <- 1:rank
