@@ -50,7 +50,7 @@
     ## adjust to avoid negative eigenvalues (if they disturb you)
     if (sqrt.dist)
         d <- sqrt(d)
-    if (is.logical(add) && isTRUE(add))
+    if (is.logical(add) && add)
         add <- "lingoes"
     if (is.character(add)) {
         add <- match.arg(add, c("lingoes", "cailliez"))
@@ -139,15 +139,20 @@
         n.group <- as.vector(table(group))
         zij <- zij*sqrt(n.group[group]/(n.group[group]-1))
     }
+    ## pre-compute group mean distance to centroid/median for `print` method
+    grp.zij <- tapply(zij, group, "mean")
     ## add in correct labels
-    colnames(vectors) <- names(eig) <- paste("PCoA", seq_along(eig), sep = "")
+    if (any(want))
+        colnames(vectors) <- names(eig) <-
+            paste("PCoA", seq_along(eig), sep = "")
     if(is.matrix(centroids))
         colnames(centroids) <- names(eig)
     else
         names(centroids) <- names(eig)
     rownames(vectors) <- names(zij) <- labs
     retval <- list(eig = eig, vectors = vectors, distances = zij,
-                   group = group, centroids = centroids, call = match.call())
+                   group = group, centroids = centroids,
+                   group.distances = grp.zij, call = match.call())
     class(retval) <- "betadisper"
     attr(retval, "method") <- attr(d, "method")
     attr(retval, "type") <- type
