@@ -1,8 +1,8 @@
 `coef.cca` <-
     function (object, norm = FALSE, ...)
 {
-    if(is.null(object$CCA))
-        stop("unconstrained models do not have coefficients")
+    if(is.null(object$CCA) || object$CCA$rank == 0)
+        stop("unconstrained or empty models do not have coefficients")
     Q <- object$CCA$QR
     u <- object$CCA$u
     ## if rank==0, the next would fail, but this kluge gives
