@@ -1,8 +1,8 @@
-"distconnected" <-
+`distconnected` <-
     function(dis, toolong = 1, trace = TRUE)
 {
     n <- attr(dis, "Size")
-    out <- .C("stepabyss", dis = as.double(dis), n = as.integer(n),
+    out <- .C(stepabyss, dis = as.double(dis), n = as.integer(n),
               toolong = as.double(toolong), val = integer(n),
               NAOK = TRUE, PACKAGE = "vegan")$val
     if (trace) {
