@@ -1,9 +1,19 @@
 `mantel` <-
-  function (xdis, ydis, method = "pearson", permutations = 999, 
-            strata = NULL, na.rm = FALSE, parallel = getOption("mc.cores")) 
+  function (xdis, ydis, method = "pearson", permutations = 999,
+            strata = NULL, na.rm = FALSE, parallel = getOption("mc.cores"))
 {
-    xdis <- as.dist(xdis)
-    ydis <- as.vector(as.dist(ydis))
+    EPS <- sqrt(.Machine$double.eps)
+    if ((is.matrix(xdis) || is.data.frame(xdis)) &&
+               isSymmetric(unname(as.matrix(xdis))))
+        xdis <- as.dist(xdis)
+    if (!inherits(xdis, "dist"))
+        stop("'xdis' must be a 'dist' object or a symmetric square matrix")
+    if ((is.matrix(ydis) || is.data.frame(ydis)) &&
+               isSymmetric(unname(as.matrix(ydis))))
+        ydis <- as.dist(ydis)
+    if (!inherits(ydis, "dist"))
+        stop("'ydis' must be a 'dist' object or a symmetric square matrix")
+    ydis <- as.vector(ydis)
     ## Handle missing values
     if (na.rm)
         use <- "complete.obs"
@@ -54,13 +64,13 @@
         } else {
             perm <- sapply(1:permutations, function(i, ...) ptest(permat[i,], ...))
         }
-        signif <- (sum(perm >= statistic) + 1)/(permutations + 1)
+        signif <- (sum(perm >= statistic - EPS) + 1)/(permutations + 1)
     }
     else {
         signif <- NA
         perm <- NULL
     }
-    res <- list(call = match.call(), method = variant, statistic = statistic, 
+    res <- list(call = match.call(), method = variant, statistic = statistic,
                 signif = signif, perm = perm, permutations = permutations,
                 control = attr(permat, "control"))
     class(res) <- "mantel"
