@@ -1,22 +1,27 @@
 `ordiParseFormula` <-
 function (formula, data, xlev = NULL, na.action = na.fail,
-          subset = NULL) 
+          subset = NULL, X)
 {
     if (missing(data))
         data <- environment(formula)
     Terms <- terms(formula, "Condition", data = data)
     flapart <- fla <- formula <- formula(Terms, width.cutoff = 500)
-    specdata <- formula[[2]]
-    X <- eval(specdata, environment(formula), enclos=globalenv())
-    ## X is usually a matrix, but it is "dist" with capscale():
-    X <- as.matrix(X)
+    ## distance-based methods (capscale, dbrda) evaluate specdata (LHS
+    ## in formula) within their code, and the handling in
+    ## ordiParseFormula is redundand and can be expensive
+    if (missing(X)) {
+        specdata <- formula[[2]]
+        X <- eval(specdata, environment(formula), enclos=globalenv())
+    }
+    X <- as.matrix(X, rownames.force = TRUE)
     indPartial <- attr(Terms, "specials")$Condition
     zmf <- ymf <- Y <- Z <- NULL
     formula[[2]] <- NULL
     if (!is.null(indPartial)) {
         partterm <- attr(Terms, "variables")[1 + indPartial]
+        ## paste() needed to combine >500 character deparsed Conditions
         Pterm <- sapply(partterm, function(x)
-            deparse(x[[2]], width.cutoff=500, backtick = TRUE))
+            paste(deparse(x[[2]], width.cutoff=500, backtick = TRUE), collapse=" "))
         Pterm <- paste(Pterm, collapse = "+")
         P.formula <- as.formula(paste("~", Pterm), env = environment(formula))
         zlev <- xlev[names(xlev) %in% Pterm]
@@ -27,15 +32,15 @@ function (formula, data, xlev = NULL, na.action = na.fail,
         else
             model.frame(P.formula, data, na.action = na.pass, xlev = zlev)
         partterm <- sapply(partterm, function(x)
-            deparse(x, width.cutoff=500, backtick = TRUE))
+            paste(deparse(x, width.cutoff=500, backtick = TRUE), collapse = " "))
         formula <- update(formula, paste("~.-", paste(partterm,
             collapse = "-")))
         flapart <- update(formula, paste(" ~ . +", Pterm))
     }
-    if (formula[[2]] == "1" || formula[[2]] == "0") 
+    if (formula[[2]] == "1" || formula[[2]] == "0")
         Y <- NULL
     else {
-        if (exists("Pterm")) 
+        if (exists("Pterm"))
             xlev <- xlev[!(names(xlev) %in% Pterm)]
 
         ymf <- if (inherits(data, "environment"))
@@ -43,7 +48,7 @@ function (formula, data, xlev = NULL, na.action = na.fail,
                 model.frame(formula, na.action = na.pass, xlev = xlev)),
                  envir=data, enclos=.GlobalEnv)
         else
-            model.frame(formula, data, na.action = na.pass, xlev = xlev) 
+            model.frame(formula, data, na.action = na.pass, xlev = xlev)
     }
     ## Combine condition an constrain data frames
     if (!is.null(zmf)) {
@@ -68,8 +73,15 @@ function (formula, data, xlev = NULL, na.action = na.fail,
     }
     ## Get na.action attribute, remove NA and drop unused levels
     if (NROW(mf) > 0) {
-        mf <- model.frame(formula(mf), mf, xlev = xlev,
-                          na.action = na.action, drop.unused.levels = TRUE)
+        ## We need to re-construct model.frame and its formula, and
+        ## for this names with functions must be back-quoted
+        ## (`poly(A1, 2)`, e.g.) with the curren scoping to find the
+        ## variable (A1) later. This happened with formula(mf) in R <
+        ## 3.6.0, but now we must be explicit.
+        mf <- model.frame(as.formula(paste("~",
+              paste(sapply(names(mf), "as.name"), collapse="+"))),
+              mf, xlev = xlev,
+              na.action = na.action, drop.unused.levels = TRUE)
         nas <- attr(mf, "na.action")
         ## Check if there are one-level factors after subset and na.action
         for (i in 1:ncol(mf))
@@ -102,18 +114,10 @@ function (formula, data, xlev = NULL, na.action = na.fail,
         else
             attr(Y, "assign") <- assign
     }
-    X <- as.matrix(X)
-    rownames(X) <- rownames(X, do.NULL = FALSE)
-    colnames(X) <- colnames(X, do.NULL = FALSE)
-    if (!is.null(Y)) {
-        rownames(Y) <- rownames(Y, do.NULL = FALSE)
-        colnames(Y) <- colnames(Y, do.NULL = FALSE)
-    }
-    if (!is.null(Z)) {
-        rownames(Z) <- rownames(Z, do.NULL = FALSE)
-        colnames(Z) <- colnames(Z, do.NULL = FALSE)
-    }
-    list(X = X, Y = Y, Z = Z, terms = terms(fla, width.cutoff = 500), 
+    X <- as.matrix(X) # if X was dist
+    rownames(X) <- rownames(X, do.NULL = FALSE, prefix = "") # if X was matrix
+    colnames(X) <- colnames(X, do.NULL = FALSE, prefix = "spe")
+    list(X = X, Y = Y, Z = Z, terms = terms(fla, width.cutoff = 500),
          terms.expand = terms(flapart, width.cutoff = 500), modelframe = mf,
          subset = subset, na.action = nas, excluded = excluded)
 }
