@@ -1,6 +1,7 @@
 `plot.ordisurf` <- function(x, what = c("contour","persp","gam"),
                             add = FALSE, bubble = FALSE, col = "red", cex = 1,
-                            nlevels = 10, levels, labcex = 0.6, ...) {
+                            nlevels = 10, levels, labcex = 0.6,
+                            lwd.cl = par("lwd"), ...) {
     what <- match.arg(what)
     y <- x$model$y
     x1 <- x$model$x1
@@ -10,7 +11,7 @@
     Z <- x$grid$z
     force(col)
     force(cex)
-    if(isTRUE(all.equal(what, "contour"))) {
+    if(what == "contour") {
         if(!add) {
             if(bubble) {
                 if (is.numeric(bubble))
@@ -23,8 +24,9 @@
             levels <- pretty(range(x$grid$z, finite = TRUE), nlevels)
         contour(X, Y, Z, col = col, add = TRUE,
                 levels = levels, labcex = labcex,
-                drawlabels = !is.null(labcex) && labcex > 0)
-    } else if(isTRUE(all.equal(what, "persp"))) {
+                drawlabels = !is.null(labcex) && labcex > 0,
+                lwd = lwd.cl)
+    } else if(what == "persp") {
         persp(X, Y, Z, col = col, cex = cex, ...)
     } else {
         class(x) <- class(x)[-1]
