@@ -6,10 +6,12 @@
     if (inherits(X, "dist") || NCOL(X) == NROW(X) &&
         isTRUE(all.equal(X, t(X))))
         stop("function cannot be used with (dis)similarities")
-    X <- as.matrix(X)
+    X <- as.matrix(X, rownames.force = TRUE)
     if (!is.null(Y)) {
-        if (is.data.frame(Y) || is.factor(Y))
+        if (is.data.frame(Y) || is.factor(Y)) { # save Y for centroids
+            mframe <- as.data.frame(Y) # can be a single factor
             Y <- model.matrix(~ ., as.data.frame(Y))[,-1,drop=FALSE]
+        }
         Y <- as.matrix(Y)
     }
     if (!is.null(Z)) {
@@ -19,6 +21,9 @@
     }
 
     sol <- ordConstrained(X, Y, Z, arg = scale, method = "rda")
+    ## mframe exists only if function was called rda(X, mframe)
+    if (exists("mframe"))
+        sol$CCA$centroids <- getCentroids(sol, mframe)
 
     call <- match.call()
     call[[1]] <- as.name("rda")
@@ -26,6 +31,9 @@
     inertia <- if (scale) "correlations" else "variance"
     sol <- c(sol,
              list("inertia" = inertia))
+    ## package klaR also has rda(): add a warning text that will be
+    ## printed if vegan::rda object is displayed with klaR:::print.rda
+    sol$regularization <- "this is a vegan::rda result object"
     class(sol) <- c("rda", "cca")
     sol
 }
