@@ -5,25 +5,12 @@
     if (missing(data)) {
         data <- parent.frame()
     } else {
-        data <- eval(match.call()$data, environment(formula),
-                     enclos = .GlobalEnv)
+        data <- eval(match.call()$data, parent.frame(), environment(formula))
     }
     d <- ordiParseFormula(formula, data = data, na.action = na.action,
                           subset = substitute(subset))
     sol <- rda.default(d$X, d$Y, d$Z, scale)
-    if (!is.null(sol$CCA) && sol$CCA$rank > 0) {
-        centroids <- centroids.cca(sol$CCA$wa, d$modelframe)
-        if (!is.null(sol$CCA$alias))
-            centroids <- unique(centroids)
-        if (!is.null(centroids)) {
-            rs <- rowSums(centroids^2)
-            centroids <- centroids[rs > 1e-04,, drop = FALSE]
-            if (length(centroids) == 0)
-                centroids <- NULL
-        }
-        if (!is.null(centroids))
-            sol$CCA$centroids <- centroids
-    }
+    sol$CCA$centroids <- getCentroids(sol, d$modelframe)
     ## replace rda.default call
     call <- match.call()
     call[[1]] <- as.name("rda")
