@@ -35,19 +35,8 @@
                           nsim, nrow(indx)))
     ## collect data to back-transform data to the scale of observations
     sqnr1 <- sqrt(nobs(object) - 1)
-    ## the ifs are only needed to cope with pre-2.5-0 vegan: now
-    ## we always have Ybar, but earlier we needed to check whether
-    ## we had CA or CCA Xbar
-    if (!is.null(object$Ybar)) {
-        cnt <- attr(object$Ybar, "scaled:center")
-        scl <- attr(object$Ybar, "scaled:scale")
-    } else { # needed for vegan-2.4 compatibility
-        if (is.null(object$CCA))
-            tmp <- object$CA$Xbar
-        else tmp <- object$CCA$Xbar
-        cnt <- attr(tmp, "scaled:center")
-        scl <- attr(tmp, "scaled:scale")
-    }
+    cnt <- attr(object$Ybar, "scaled:center")
+    scl <- attr(object$Ybar, "scaled:scale")
 
     ## Proper simulation: very similar for simulate.lm, but produces
     ## an array of response matrices
@@ -80,10 +69,10 @@
                                 function(x) mvrnorm(1, mu = x, Sigma = dev)))
         }
         ## ans to the scale of observations
-        ans[,,i] <- ans[,,i] * sqnr1
+        ans[,,i] <- ans[,,i, drop = FALSE] * sqnr1
         if (!is.null(scl))
-            ans[,,i] <- sweep(ans[,,i], 2, scl, "*")
-        ans[,,i] <- sweep(ans[,,i], 2, cnt, "+")
+            ans[,,i] <- sweep(ans[,,i, drop = FALSE], 2, scl, "*")
+        ans[,,i] <- sweep(ans[,,i, drop = FALSE], 2, cnt, "+")
     }
     ## set RNG attributes
     if (is.null(indx))
@@ -97,7 +86,11 @@
     } else {
         dimnames(ans) <- list(rownames(ftd), colnames(ftd),
                               paste("sim", seq_len(nsim), sep = "_"))
-        attr(ans, "data") <- round(ftd + CAYbar, 12)
+        orig <- (ftd + CAYbar) * sqnr1
+        if (!is.null(scl))
+            orig <- sweep(orig, 2, scl, "*")
+        orig <- sweep(orig, 2, cnt, "+")
+        attr(ans, "data") <- round(orig, 12)
         attr(ans, "method") <- paste("simulate", ifelse(is.null(indx),
                                                         "parametric", "index"))
         attr(ans, "binary") <- FALSE
