@@ -1,8 +1,7 @@
-`summary.prc` <-
-    function (object, axis = 1, scaling = 3, digits = 4, ...)
-{
+`summary.prc` <- function (object, axis = 1, scaling = "sites", const,
+                           digits = 4, correlation = FALSE, ...) {
     sc = scores(object, scaling = scaling, display = c("sp", "lc"),
-                           choices=axis, ...)
+                choices = axis, correlation = correlation, const = const,...)
     ## coef for scaled sites (coef(object) gives for orthonormal)
     b <- qr.coef(object$CCA$QR, sc$constraints)
     prnk <- object$pCCA$rank
