@@ -5,7 +5,7 @@
     tree <- as.hclust(tree)
     if (any(diff(tree$height) < -sqrt(.Machine$double.eps)))
         stop("tree with reversals cannot be handled")
-    x <- as.matrix(x)
+    x <- as.matrix(x, rownames.force = TRUE)
     n <- nrow(x)
     ABJ <- matrix(0, n , n)
     dmat <- as.matrix(cophenetic(tree))
