@@ -14,6 +14,11 @@ C 1.02 January 7, 2016 - fixed bug in MONREG so that huge
 C                        dissimilarities are correctly handled in
 C                        creating the initial partition for monotone 
 C                        regression with primary tie treatment.
+C 1.03 April 11, 2023 - changed calculation of M in ASORT4 from
+C                       exponentiation to use of ISHIFT to avoid a
+C                       problem with some optimizing compilers
+C 1.04 March 8, 2024  - removed the use of ALLOCATABLE arrays by making
+C                       IWORK, GRAD, and GRLAST permananet local arrays
 C
 C Written by Dr. Peter R. Minchin
 C            Department of Biological Sciences
@@ -137,18 +142,19 @@ C---OUTPUT ARGUMENTS
       INTEGER, INTENT(OUT) :: ITERS, ICAUSE
       DOUBLE PRECISION, INTENT(OUT) :: X(NOBJ,NDIM), DIST(NDIS), 
      .  DHAT(NDIS), STRESS, STRS(NGRP)
-C---ALLOCATABLE TEMPORARY ARRAYS
-      INTEGER, ALLOCATABLE :: IWORK(:)
-      DOUBLE PRECISION, ALLOCATABLE :: GRAD(:,:), GRLAST(:,:)
+C-Removed the use of allocatable arrays (v 1.04)
+C---TEMPORARY ARRAYS
+      INTEGER :: IWORK(NDIS)
+      DOUBLE PRECISION :: GRAD(NOBJ,NDIM), GRLAST(NOBJ,NDIM)
 C
       DOUBLE PRECISION :: STRLST, SQRTN, SRATF1, SRATF2, FNGRP,
      .  STRINC, COSAV, ACOSAV, SRATAV, STEP, FNDIM, SFGR, SRATIO,
      .  SFACT, TFACT, DMEAN, CAGRGL, SFGLST, STPNEW, SSFACB, SSFACT,
      .  PARAM(2)
-C
+C-Removed the use of allocatable arrays (v 1.04)
 C ALLOCATE THE TEMPORARY ARRAYS NEEDED
-C
-      ALLOCATE (IWORK(NDIS), GRAD(NOBJ,NDIM), GRLAST(NOBJ,NDIM))
+C 
+C      ALLOCATE (IWORK(NDIS), GRAD(NOBJ,NDIM), GRLAST(NOBJ,NDIM))
 C
 C INITIALIZE SOME PARAMETERS
 C
@@ -354,9 +360,10 @@ C END OF ITERATION LOOP
 C
 C=======================================================================
 C
+C-Removed the use of allocatable arrays (v 1.04)
 C DEALLOCATE THE TEMPORARY ARRAYS AND RETURN
 C
-      DEALLOCATE (IWORK, GRAD, GRLAST)
+C      DEALLOCATE (IWORK, GRAD, GRLAST)
       RETURN
       END SUBROUTINE monoMDS
 
@@ -382,7 +389,10 @@ C
       IF (N.LT.2) RETURN
       FN=REAL(N)
       NLOOPS=MAX(NINT(LOG(FN)/LOG(2.)),1)
-      M=2**(NLOOPS-1)
+C REPLACED EXPONENTIATION BY ISHFT TO AVOID A PROBLEM WITH SOME
+C   OPTIMIZING COMPILERS (v 1.03)
+C      M=2**(NLOOPS-1)
+      M=ISHFT(1, NLOOPS-1)
       DO II=1,NLOOPS
         FM=M
         DO I=1,MAX(1,N-M)
@@ -740,33 +750,6 @@ C
       RETURN
       END SUBROUTINE MAINIT
 
-      SUBROUTINE MAMAB (A,B,L,M,N,MAXL1,MAXM,C,MAXL2)
-C
-C MATRIX MULTIPLICATION C=A.B
-C
-C MATRIX A(L,M) is multiplied by B(M,N) to give C(L,N)
-C
-C Written by Dr. Peter R. Minchin
-C            Department of Biological Sciences
-C            Southern Illinois University Edwardsville
-C            PO Box 1651
-C            Edwardsville, IL 62026-1651, U.S.A.
-C            Phone: +1-618-650-2975   FAX: +1-618-650-3174
-C            Email: pminchi@siue.edu
-C
-      DOUBLE PRECISION A(MAXL1,M), B(MAXM,N), C(MAXL2,N)
-C
-      DO I=1,L
-        DO J=1,N
-          C(I,J)=0.0
-          DO K=1,M
-            C(I,J)=C(I,J)+A(I,K)*B(K,J)
-          ENDDO
-        ENDDO
-      ENDDO
-      RETURN
-      END SUBROUTINE MAMAB
-
       SUBROUTINE MAMAS (A,MAXL,L,M,S)
 C
 C MULTIPLY MATRIX A(L,M) BY THE SCALAR S
@@ -789,88 +772,6 @@ C
       RETURN
       END SUBROUTINE MAMAS
 
-      SUBROUTINE MAMATA (A,L,M,MAXL,B,MAXM)
-C
-C MATRIX MULTIPLICATION B=A'.A
-C
-C The transpose of matrix A(L,M) is multiplied A(L,M) to give B(M,M)
-C
-C Written by Dr. Peter R. Minchin
-C            Department of Biological Sciences
-C            Southern Illinois University Edwardsville
-C            PO Box 1651
-C            Edwardsville, IL 62026-1651, U.S.A.
-C            Phone: +1-618-650-2975   FAX: +1-618-650-3174
-C            Email: pminchi@siue.edu
-C
-      DOUBLE PRECISION A(MAXL,M), B(MAXM,M)
-C
-C COMPUTE B
-C
-      DO I=1,M
-        DO J=1,I
-          B(I,J)=0.0
-          DO K=1,L
-            B(I,J)=B(I,J)+A(K,I)*A(K,J)
-          ENDDO
-          B(J,I)=B(I,J)
-        ENDDO
-      ENDDO
-      RETURN
-      END SUBROUTINE MAMATA
-
-      SUBROUTINE MANORM (A,MAXL,L,M,IOP)
-C
-C NORMALIZE THE ROWS (IOP=1) OR COLUMNS (IOP=2) OF THE MATRIX A(L,M)
-C   (I.E. ADJUST THE SUMS OF SQUARED ELEMENTS TO 1.0).
-C
-C Written by Dr. Peter R. Minchin
-C            Department of Biological Sciences
-C            Southern Illinois University Edwardsville
-C            PO Box 1651
-C            Edwardsville, IL 62026-1651, U.S.A.
-C            Phone: +1-618-650-2975   FAX: +1-618-650-3174
-C            Email: pminchi@siue.edu
-C
-      DOUBLE PRECISION A(MAXL,M), SUMSQ, FACTOR, SMALL
-C
-      SMALL=SQRT(EPSILON(SUMSQ))
-C
-C NORMALIZE ROWS
-C
-      IF (IOP.EQ.1) THEN
-        DO I=1,L
-          SUMSQ=0.0D0
-          DO J=1,M
-            SUMSQ=SUMSQ+A(I,J)*A(I,J)
-          ENDDO
-          IF (SUMSQ.GT.SMALL) THEN
-            FACTOR=1.0/SQRT(SUMSQ)
-            DO J=1,M
-              A(I,J)=A(I,J)*FACTOR
-            ENDDO
-          ENDIF
-        ENDDO
-C
-C NORMALIZE COLUMNS
-C
-      ELSE
-        DO J=1,M
-          SUMSQ=0.0D0
-          DO I=1,L
-            SUMSQ=SUMSQ+A(I,J)*A(I,J)
-          ENDDO
-          IF (SUMSQ.GT.SMALL) THEN
-            FACTOR=1.0/SQRT(SUMSQ)
-            DO I=1,L
-              A(I,J)=A(I,J)*FACTOR
-            ENDDO
-          ENDIF
-        ENDDO
-      ENDIF
-      RETURN
-      END SUBROUTINE MANORM
- 
       SUBROUTINE MONREG (DISS,DIST,DHAT,IIDX,JIDX,IWORK,N,ITIES)
 C
 C PERFORMS KRUSKAL'S MONOTONE REGRESSION OF DIST ON DISS, PLACING THE 
